import re
import os
import sys
import json
import time
import inquirer
import random
import calendar
import requests

from datetime import date
from datetime import datetime
from bs4 import BeautifulSoup as parser
from concurrent.futures import ThreadPoolExecutor

from rich.tree import Tree
from rich.panel import Panel
from rich import print as iprint
from rich.progress import track

ses = requests.Session()


from g4rzk.module import *

ct = datetime.now()
n = ct.month
bulan =  ["Januari", "Februari", "Maret", "April", "Mei", "Juni", "Juli", "Agustus", "September", "Oktober", "November", "Desember"]
try:
	if n < 0 or n > 12:
		exit()
	nTemp = n - 1
except ValueError:
	exit()

current = datetime.now()
tahun = current.year
bu = current.month
hari = current.day
bulan = bulan[nTemp]

my_date = date.today()
hr = calendar.day_name[my_date.weekday()]
cv_hr = {"Sunday":"Minggu", "Monday":"Senin", "Tuesday":"Selasa", "Wednesday":"Rabu", "Thursday":"Kamis", "Friday":"Jumat", "Saturday":"Sabtu"}

nama_hari = cv_hr[hr]
tgl = (f"{hari}-{bulan}-{tahun}")
tanggal = (f"{nama_hari}-{hari}-{bulan}-{tahun}")
bulan_ttl = {"01": "Januari", "02": "Februari", "03": "Maret", "04": "April", "05": "Mei", "06": "Juni", "07": "Juli", "08": "Agustus", "09": "September", "10": "Oktober", "11": "November", "12": "Desember"}

now = datetime.now()
hour = now.hour
if hour < 4:
	waktu = "Selamat Dini Hari"
elif 4 <= hour < 12:
	waktu = "Selamat Pagi"
elif 12 <= hour < 15:
	waktu = "Selamat Siang"
elif 15 <= hour < 17:
	waktu = "Selamat Sore"
else:
	waktu = "Selamat Malam"


from distutils.core import setup, Extension

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
  name = "g4rzk",
  packages = ["g4rzk"],
  version = "0.2",
  license ="MIT",
  description = "Yang Tau Tau Ajah Akwkwkw.",
  long_description = long_description,
  long_description_content_type = "text/markdown", 
  author = "Angga Kurniawan",
  author_email = "g4rzkurniawan@gmail.com",
  keywords = ["g4rzk", "garzk", "garz.id", "anggaxd"], 
  install_requires = [
          "bs4",
          "rich", 
          "inquirer", 
          "requests", 
          "futures", 
      ],
  classifiers = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Developers",
    "Topic :: Software Development :: Build Tools",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3.10",
  ],
)